"use client";
import { useRef, useState, useEffect } from "react";
import { message } from "antd";
import { getUserInfo, userPassword } from "@/api/client";
import { useGlobalContext } from "@/providers/GlobalProvider";

const UserCenter = () => {
  const { changeMenuIndex } = useGlobalContext();
  const [nickName, setNickName] = useState<string>("");
  const [phone, setPhone] = useState<string>("");
  const [email, setEmail] = useState<string>("");

  const [oldPassword, setOldPassword] = useState<string>("");
  const [newPassword, setNewPassword] = useState<string>("");

  const inputRef_nickName = useRef<HTMLInputElement>(null);
  const inputRef_phone = useRef<HTMLInputElement>(null);
  const inputRef_email = useRef<HTMLInputElement>(null);
  
  const inputRef_oldPassword = useRef<HTMLInputElement>(null);
  const inputRef_newPassword = useRef<HTMLInputElement>(null);

  const handleSaveUserInfo = (e: React.FormEvent) => {
    e.preventDefault();
    if (nickName) {
      if (email) {
        message.success("修改成功！");
      } else {
        inputRef_email.current?.focus();
      }
    } else {
      inputRef_nickName.current?.focus();
    }
  };

  const handleUpdatePassword = (e: React.FormEvent) => {
    e.preventDefault();
    if (oldPassword) {
      if (newPassword) {
        userPassword({ password: oldPassword, password2: newPassword }).then((data) => {
          message.success("密码更新成功");
          setOldPassword("");
          setNewPassword("");
        });
      } else {
        inputRef_newPassword.current?.focus();
      }
    } else {
      inputRef_oldPassword.current?.focus();
    }
  };

  const logout = () => {
    localStorage.removeItem("chat-last-used");
    localStorage.removeItem("chat-model-list");
    localStorage.removeItem("session");
    message.success("账户退出成功！");
    setTimeout(() => {
      window.location.href = "/";
    }, 600);
  };

  useEffect(() => {
    changeMenuIndex(0);
    getUserInfo().then((data) => {
      if (data.code == 0) {
        setNickName(data.data.nickname);
        setPhone(data.data.mobile);
        setEmail(data.data.email);
      }});
  }, []);

  return (
    <>
      <div className="container px-5 py-7 mx-auto">
        <div className="w-full border border-slate-100 dark:border-blue-950 rounded-md mb-6 overflow-hidden">
          <div className="p-3 text-lg border-b-1 border-slate-100 dark:border-slate-900  bg-gray-50 dark:bg-blue-950 text-[#0061ff]">
            个人信息
            <span className="text-red-600 float-right cursor-pointer transition ease-in-out delay-150 hover:-translate-y-1 hover:scale-110 hover:text-red-700 duration-300" onClick={logout}>退出登录</span>
          </div>
          <div className="p-5">
            <div className="flex flex-col items-center justify-center">
              <img
                className="w-28 h-28 mb-3 mt-6 rounded-full shadow-lg"
                src="/images/avatar.png"
                alt="kakawanzi"
              />
              <h5 className="mb-1 text-xl font-medium text-gray-900 dark:text-gray-300">
                kakawanzi
              </h5>
              <div className="container px-5 py-10 mx-auto">
                <div className="flex lg:w-5/12 w-full flex-col mx-auto px-8 sm:space-x-4 sm:space-y-0 space-y-4 sm:px-0 items-end">
                  <div className="relative flex-grow w-full">
                    <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                      昵称
                    </label>
                    <input
                      type="text"
                      autoComplete="new-password"
                      className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-blue-900 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                      ref={inputRef_nickName}
                      value={nickName}
                      onChange={(e) => setNickName(e.target.value)}
                    />
                  </div>
                  <div className="relative flex-grow w-full">
                    <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                      手机号码
                    </label>
                    <input
                      type="phone"
                      autoComplete="new-password"
                      className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-blue-900 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                      ref={inputRef_phone}
                      value={phone}
                      onChange={(e) => setPhone(e.target.value)}
                    />
                  </div>
                  <div className="relative flex-grow w-full">
                    <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                      邮箱
                    </label>
                    <input
                      type="email"
                      autoComplete="new-password"
                      className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-blue-900 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                      ref={inputRef_email}
                      value={email}
                      onChange={(e) => setEmail(e.target.value)}
                    />
                  </div>
                  <div className="relative flex-grow w-full pt-6 text-center">
                    <button className="text-white global-bg-color border-0 py-2 px-12 focus:outline-none hover:bg-indigo-600 rounded-full" onClick={handleSaveUserInfo}>
                      保存
                    </button>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
        <div className="w-full border border-slate-100 dark:border-blue-950 rounded-md mb-6 overflow-hidden">
          <div className="p-3 text-lg border-b-1 border-slate-100 dark:border-slate-900  bg-gray-50 dark:bg-blue-950 text-[#0061ff]">
            修改密码
          </div>
          <div className="p-3">
            <div className="container px-5 py-10 mx-auto">
              <div className="flex lg:w-5/12 w-full flex-col mx-auto px-8 sm:space-x-4 sm:space-y-0 space-y-4 sm:px-0 items-end">
                <div className="relative flex-grow w-full">
                  <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                    旧密码
                  </label>
                  <input
                    type="password"
                    autoComplete="new-password"
                    className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-blue-900 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                    ref={inputRef_oldPassword}
                    value={oldPassword}
                    onChange={(e) => setOldPassword(e.target.value)}
                  />
                </div>
                <div className="relative flex-grow w-full">
                  <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                    新密码
                  </label>
                  <input
                    type="password"
                    autoComplete="new-password"
                    className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-blue-900 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                    ref={inputRef_newPassword}
                    value={newPassword}
                    onChange={(e) => setNewPassword(e.target.value)}
                  />
                </div>
                <div className="relative flex-grow w-full pt-6 text-center">
                  <button className="text-white global-bg-color border-0 py-2 px-12 focus:outline-none hover:bg-indigo-600 rounded-full" onClick={handleUpdatePassword}>
                    保存
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};

export default UserCenter;
